aind\_behavior\_curriculum.curriculum.Stage
===========================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: Stage
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Stage.__init__
      ~Stage.add_policy
      ~Stage.add_policy_transition
      ~Stage.construct
      ~Stage.copy
      ~Stage.dict
      ~Stage.from_orm
      ~Stage.get_task
      ~Stage.get_task_parameters
      ~Stage.json
      ~Stage.model_construct
      ~Stage.model_copy
      ~Stage.model_dump
      ~Stage.model_dump_json
      ~Stage.model_json_schema
      ~Stage.model_parametrized_name
      ~Stage.model_post_init
      ~Stage.model_rebuild
      ~Stage.model_validate
      ~Stage.model_validate_json
      ~Stage.model_validate_strings
      ~Stage.parse_file
      ~Stage.parse_obj
      ~Stage.parse_raw
      ~Stage.remove_policy
      ~Stage.remove_policy_transition
      ~Stage.schema
      ~Stage.schema_json
      ~Stage.see_policies
      ~Stage.see_policy_transitions
      ~Stage.set_policy_transition_priority
      ~Stage.set_start_policies
      ~Stage.set_task
      ~Stage.set_task_parameters
      ~Stage.update_forward_refs
      ~Stage.validate
      ~Stage.validate_stage
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Stage.model_computed_fields
      ~Stage.model_config
      ~Stage.model_extra
      ~Stage.model_fields
      ~Stage.model_fields_set
      ~Stage.name
      ~Stage.task
      ~Stage.graph
      ~Stage.start_policies
      ~Stage.metrics_provider
   
   